@@ -289,6 +289,8 @@ class Tester:
         # note, presimp=0 is braindead for preproc but it's mostly 1 so OK
         cmd += "--presimp %d " % random.choice([1, 1, 1, 1, 1, 1, 1, 0])
         cmd += "--confbtwsimp %d " % random.choice([100, 1000])
+        cmd += "--everylev1 %d " % random.choice([122, 1222, 12222])
+        cmd += "--everylev2 %d " % random.choice([133, 1333, 14444])
 
         if self.dump_red is not None:
             cmd += "--dumpred %s " % self.dump_red
@@ -659,6 +661,7 @@ class Tester:
             fuzzer_call_failed(fname)
 
         if not self.drat and not self.only_indep and not self.dump_red:
+            print("->Multipart test")
             self.needDebugLib = True
             interspersed_fname = unique_file("fuzzTest")
             seed_for_inters = random.randint(0, 1000000)
@@ -812,7 +815,6 @@ fuzzers_xor = [
 
 
 if __name__ == "__main__":
-    global options
     global fuzzers_drat
     global fuzzers_nodrat
     if not os.path.isdir("out"):
