@@ -31,6 +31,8 @@ OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWA
 
 namespace CMSat {
 
+class Watched;
+
 //=================================================================================================
 // Automatically resizable arrays
 //
@@ -295,6 +297,17 @@ void vec<T>::clear(bool dealloc)
     }
 }
 
+template<>
+inline void vec<Watched>::clear(bool dealloc)
+{
+    if (data != NULL) {
+        sz = 0;
+        if (dealloc) {
+            free(data), data = NULL, cap = 0;
+        }
+    }
+}
+
 //=================================================================================================
 }
 
