@@ -407,7 +407,7 @@ void PropEngine::enqueue(const Lit p, const PropBy from)
         watches.prefetch((~p).toInt());
     }
 
-    if (!update_bogoprops && !VSIDS) {
+    if (!update_bogoprops && !VSIDS && from != PropBy()) {
         varData[v].last_picked = sumConflicts;
         varData[v].conflicted = 0;
 
