@@ -89,7 +89,7 @@ DLL_PUBLIC SolverConf::SolverConf() :
         , print_all_restarts (false)
         , verbStats        (0)
         , do_print_times(1)
-        , print_restart_line_every_n_confl(4096)
+        , print_restart_line_every_n_confl(8192)
 
         //Limits
         , maxTime          (std::numeric_limits<double>::max())
@@ -153,9 +153,9 @@ DLL_PUBLIC SolverConf::SolverConf() :
 
         //XOR
         , doFindXors       (true)
-        , maxXorToFind     (5)
+        , maxXorToFind     (7)
+        , maxXorToFindSlow (5)
         , useCacheWhenFindingXors(false)
-        , doEchelonizeXOR  (true)
         , maxXORMatrix     (400ULL)
         #ifndef USE_GAUSS
         , xor_finder_time_limitM(50)
