@@ -28,6 +28,8 @@ THE SOFTWARE.
 #include <iostream>
 #include <algorithm>
 #include <set>
+#include <limits>
+#include "constants.h"
 #include "xor.h"
 #include "cset.h"
 #include "watcharray.h"
@@ -62,7 +64,8 @@ class PossibleXor
             cout << "Trying to create XOR from clause: " << cl << endl;
             #endif
 
-            assert(cl.size() <= sizeof(origCl)/sizeof(Lit));
+            assert(cl.size() <= sizeof(origCl)/sizeof(Lit)
+            && "The XOR being recovered is larger than MAX_XOR_RECOVER_SIZE");
             for(size_t i = 0; i < size; i++) {
                 origCl[i] = cl[i];
                 if (i > 0)
@@ -128,7 +131,7 @@ class PossibleXor
         // 0 1 0
         // 0 0 1
         vector<char> foundComb;
-        Lit origCl[8];
+        Lit origCl[MAX_XOR_RECOVER_SIZE];
         cl_abst_type abst;
         uint32_t size;
         bool rhs;
@@ -161,6 +164,8 @@ public:
         //XOR stats
         uint64_t foundXors = 0;
         uint64_t sumSizeXors = 0;
+        uint32_t minsize = std::numeric_limits<uint32_t>::max();
+        uint32_t maxsize = std::numeric_limits<uint32_t>::min();
     };
 
     const Stats& get_stats() const;
